<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       http://www.codetides.com/
 * @since      3.2.3
 *
 * @package    Advanced_Floating_Content
 * @subpackage Advanced_Floating_Content/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      3.0
 * @package    Advanced_Floating_Content
 * @subpackage Advanced_Floating_Content/includes
 * @author     Code Tides <contact@codetides.com>
 */
class Advanced_Floating_Content {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Advanced_Floating_Content_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {

		$this->plugin_name = 'advanced-floating-content';
		$this->version = '1.0.0';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Advanced_Floating_Content_Loader. Orchestrates the hooks of the plugin.
	 * - Advanced_Floating_Content_i18n. Defines internationalization functionality.
	 * - Advanced_Floating_Content_Admin. Defines all hooks for the admin area.
	 * - Advanced_Floating_Content_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-advanced-floating-content-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-advanced-floating-content-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-advanced-floating-content-admin.php';       
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/function-advanced-floating-content-admin.php';
        
        /*
            This class responsible for checking license of user
        */
        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-advanced-floating-content-license-checker.php';
        
		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-advanced-floating-content-public.php';
        
        
     
        
		$this->loader = new Advanced_Floating_Content_Loader();
     
	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Advanced_Floating_Content_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Advanced_Floating_Content_i18n();
		$plugin_i18n->set_domain( $this->get_plugin_name() );

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Advanced_Floating_Content_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		$this->loader->add_action( 'init', $plugin_admin, 'register_cpt_floating_content' );
		$this->loader->add_action( 'add_meta_boxes', $plugin_admin,  'add_meta_box' );
		$this->loader->add_action( 'save_post',$plugin_admin, 'save_meta_box' );
		$this->loader->add_action( 'add_meta_boxes', $plugin_admin,  'add_meta_box_premium' );
		$this->loader->add_action('admin_menu', $plugin_admin, 'replace_submit_meta_box');
		$this->loader->add_filter('post_updated_messages',  $plugin_admin, 'floating_content_custom_messages');
		$this->loader->add_filter( 'post_row_actions', $plugin_admin, 'duplicate_floating_content',10,2);
		$this->loader->add_filter( 'page_row_actions', $plugin_admin, 'duplicate_floating_content',10,2);
		$this->loader->add_action( 'admin_action_floating_content_duplicate_post', $plugin_admin, 'floating_content_duplicate_post' );
		$this->loader->add_action( 'admin_head-edit.php', $plugin_admin, 'floating_content_customized_quick_edit' );
		$this->loader->add_filter('manage_edit-ct_afc_columns',  $plugin_admin, 'floating_content_columns');
		$this->loader->add_action( 'manage_ct_afc_posts_custom_column',  $plugin_admin,'floating_content_columns_data', 10, 2 );
        
        
        
        $this->loader->add_action('admin_footer', $plugin_admin, 'update_notice_status_javascript' );
       //$this->loader->add_action('wp_ajax_update_notice_status', $plugin_admin, 'update_notice_status' );
        //$this->loader->add_action( 'wp_ajax_nopriv_update_notice_status', $plugin_admin, 'update_notice_status' );
        
        /*
        * Support Notification
        */        
        $this->loader->add_action( 'wp_ajax_update_remind_later',  $plugin_admin, 'update_remind_later' );
        $this->loader->add_action( 'wp_ajax_nopriv_update_remind_later', $plugin_admin, 'update_remind_later' );
        $this->loader->add_action( 'wp_ajax_update_no_thanks',  $plugin_admin, 'update_no_thanks' );
        $this->loader->add_action( 'wp_ajax_nopriv_update_no_thanks', $plugin_admin, 'update_no_thanks' );
        /*
        * Support Notification
        */ 
        
		$this->loader->add_action( 'wp_ajax_update_control_imp_ips',  $plugin_admin, 'update_control_imp_ips' );
		
	//	$this->loader->add_action( 'admin_head-post.php',  $plugin_admin, 'validate_publish_admin_hook' );
	//	$this->loader->add_action( 'admin_head-post-new.php',  $plugin_admin, 'validate_publish_admin_hook' );
	//	$this->loader->add_action( 'wp_ajax_pre_submit_validation',  $plugin_admin, 'pre_submit_validation' );
		

		
		
        /*
        * Rating Notification
        */
        $this->loader->add_action( 'wp_ajax_update_remind_later_review',  $plugin_admin, 'update_remind_later_review' );
        $this->loader->add_action( 'wp_ajax_nopriv_update_remind_later_review', $plugin_admin, 'update_remind_later_review' );
        $this->loader->add_action( 'wp_ajax_update_reviewed',  $plugin_admin, 'update_reviewed' );
        $this->loader->add_action( 'wp_ajax_nopriv_update_reviewed', $plugin_admin, 'update_reviewed' );
        /*
        * Rating Notification
        */
        
      //  $this->loader->add_action( 'admin_notices',$plugin_admin, 'floating_content_admin_notice' );   
        
         /*        
            add statistics and licence checker pages in content monetizer Pro
        */      
                
        $this->loader->add_action( 'admin_menu', $plugin_admin, 'add_submenu_pages' );
        $this->loader->add_action( 'admin_init', $plugin_admin, 'initialize_afc_options' );
        $this->loader->add_action( 'admin_notices',$plugin_admin, 'afc_admin_notice' );
		
		$this->loader->add_filter('admin_footer_text', $plugin_admin, 'afc_add_credits');
		
		
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Advanced_Floating_Content_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );
		$this->loader->add_action('wp_footer', $plugin_public, 'load_floating_content');
        $this->loader->add_action('wp_ajax_controlImpressions', $plugin_public, 'controlImpressions' );
        $this->loader->add_action( 'wp_ajax_nopriv_controlImpressions', $plugin_public, 'controlImpressions' );
        
        $this->loader->add_action('wp_ajax_display_floating_content', $plugin_public, 'display_floating_content' );
        $this->loader->add_action( 'wp_ajax_nopriv_display_floating_content', $plugin_public, 'display_floating_content' );
        
        
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Advanced_Floating_Content_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
